pub struct RustParser { /* private fields */ }Expand description
A wrapper around tree-sitter for parsing Rust source code.
Implementations
Sourceimpl RustParser
impl RustParser
Sourcepub fn new() -> Result<Self, ParseError>
pub fn new() -> Result<Self, ParseError>
Sourcepub fn parse(&mut self, source: &str) -> Option<Tree>
pub fn parse(&mut self, source: &str) -> Option<Tree>
Parses the given source code into a syntax tree.
Sourcepub fn parse_file(&mut self, path: &Path) -> Result<(String, Tree), ParseError>
pub fn parse_file(&mut self, path: &Path) -> Result<(String, Tree), ParseError>
Sourcepub fn create_query(&self, query_str: &str) -> Result<Query, ParseError>
pub fn create_query(&self, query_str: &str) -> Result<Query, ParseError>
Creates a query for matching patterns in the syntax tree.
Errors
Returns an error if the query is invalid.